# fpga_i2c_bridge
A library for managing and remotely controlling devices connected to one or several bridges, which in turn are communicated with via a specialized I²C protocol. Intended for a Smart Home FPGA that was created as part of a Bacherlor's thesis on the subject.

A more comprehensive description will follow shortly.

## Installation
```
pip install fpga-i2c-bridge
```

## Usage
### Interactive shell
Run the interactive I2C shell with
```
python -m fpga_i2c_bridge
```

Use the `--dummy` switch to run with simulated dummy devices.

### API
Under construction
